package Qt::Gui::QDial;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QDial
# file     : QtGui/qdial.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QAbstractSlider/;
#our @ISA = qw/Qt::Gui::QAbstractSlider/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QDial

=head1 PUBLIC METHODS

=over

=item   QDial(QWidget * parent)

=item   QDial(QWidget * parent = 0)

=item   ~QDial()

=item  QSize minimumSizeHint()

=item  int notchSize()

=item  qreal notchTarget()

=item  bool notchesVisible()

=item  void setNotchTarget(double target)

=item  void setNotchesVisible(bool visible)

=item  void setWrapping(bool on)

=item  QSize sizeHint()

=item  bool wrapping()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
